@@ -3,6 +3,16 @@ class HttpError(BaseException):
     def __init__(self, code):
         self.code = code
 
+class Http400(HttpError):
+    """ Exception used to respond with a 403, instead of a success and data """
+    def __init__(self):
+        super(Http400, self).__init__(400)
+
+class Http401(HttpError):
+    """ Exception used to respond with a 403, instead of a success and data """
+    def __init__(self):
+        super(Http401, self).__init__(401)
+
 class Http403(HttpError):
     """ Exception used to respond with a 403, instead of a success and data """
     def __init__(self):
