@@ -64,7 +64,7 @@ class Request(object):
         self.form_data  = {}
         self.method     = env.get('REQUEST_METHOD')
 
-        if self.method == 'POST':
+        if self.method == 'POST' or self.method == 'PUT':
             self.form_vals  = env['wsgi.input'].read()
             self.form_data  = parse_qs(self.form_vals)
 
