@@ -7,23 +7,34 @@ import re
 
 from content_types import *
 
+HTTP_METHODS = [ "OPTIONS", "GET", "HEAD", "POST", "PUT", "DELETE", "TRACE", "CONNECT" ]
+
 '''________________________________Routes____________________________________'''
 
 class Routes(object):
     """ Route, and handler, container used for a `gserver` """
-    def __init__(self, setup_func=None):
+    def __init__(self):
         self._routes = {}
-        self._setup_func = setup_func
+        self._before_funcs = ()
+        self._after_funcs = ()
 
-    def setup_func(self, fn):
+    def before(self, fn):
         """ Sets a function to be called prior to the route being invoked.
             Functions signature should be `fn(Request)` 
 
             (can be used to set things like a logged in user prior to invoking the route)
         """
-        self._setup_func = fn
+        self._before_funcs = (fn,) + self._before_funcs
     
-    def route(self, path, method='GET', content_type=TEXT.HTML, setup_func=None):
+    def after(self, fn):
+        """ Sets a function to be called after the route being invoked.
+            Functions signature should be `fn(Request)` 
+
+            (can be used to set things like a logged in user prior to invoking the route)
+        """
+        self._after_funcs = (fn,) + self._after_funcs
+    
+    def route(self, path, method='GET', content_type=TEXT.HTML):
         """ DECORATOR - Decorates a function as a route handler.
 
         Args:
@@ -38,19 +49,27 @@ class Routes(object):
                     h, v = content_type
                     req.add_header(h, v)
 
-                if self._setup_func:
-                    self._setup_func(req)
-                if setup_func:
-                    setup_func(req)
+                if self._before_funcs:
+                    for fn in self._before_funcs:
+                        fn(req)
 
                 if kwargs:
-                    return handler(req, **kwargs)
+                    resp = handler(req, **kwargs)
                 else:
-                    return handler(req)
+                    resp = handler(req)
+
+                if self._after_funcs:
+                    for fn in self._after_funcs:
+                        fn(req)
+
+                return resp
 
             self._routes[regex] = wrapper   # Add the route to the collection
             wrapper.method = method
-            wrapper.methods = method.split(',')
+            if method == "*":
+                wrapper.methods = HTTP_METHODS
+            else:
+                wrapper.methods = method.split(',')
             wrapper.content_type = content_type
 
             return wrapper
